@@ -101,9 +101,7 @@ def jslint(files, fix = False, relax = False):
     options.append('--jslint_error=optional_type_marker')
     options.append('--jslint_error=blank_lines_at_top_level')
     options.append('--jslint_error=indentation')
-    options.append('--custom_jsdoc_tags=version,ignore,returns,example,function,requires,name,\
-                                        namespace,property,static,constant,default,location,\
-                                        copyright,memberOf,lends,fileOverview')
+    options.append('--custom_jsdoc_tags=version,ignore,returns,example,function,requires,name,namespace,property,static,constant,default,location,copyright,memberOf,lends,fileOverview')
 
 
     if fix == True:
